@@ -1,7 +1,7 @@
 // qjackctlSystemTray.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2006, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2007, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,38 +22,87 @@
 #ifndef __qjackctlSystemTray_h
 #define __qjackctlSystemTray_h
 
-#include <qlabel.h>
-#include <qpixmap.h>
+#include <QWidget>
+
+#if QT_VERSION >= 0x040200
+#include <QSystemTrayIcon>
+#else
+#include <QIcon>
+#endif
 
 
 //----------------------------------------------------------------------------
 // qjackctlSystemTray -- Custom system tray widget.
 
-class qjackctlSystemTray : public QLabel
+#if QT_VERSION >= 0x040200
+class qjackctlSystemTray : public QSystemTrayIcon
+#else
+class qjackctlSystemTray : public QWidget
+#endif
 {
-    Q_OBJECT
+	Q_OBJECT
 
 public:
 
-    // Constructor.
-    qjackctlSystemTray(QWidget *pParent = 0, const char *pszName = 0);
-    // Default destructor.
-    ~qjackctlSystemTray();
+	// Constructor.
+	qjackctlSystemTray(QWidget *pParent = 0);
+	// Default destructor.
+	~qjackctlSystemTray();
+
+	// Background mask methods.
+	void setBackground(const QColor& background);
+	const QColor& background() const;
 
     // Set system tray icon overlay.
     void setPixmapOverlay(const QPixmap& pmOverlay);
+	const QPixmap& pixmapOverlay() const;
+
+	// System tray icon/pixmaps update method.
+	void updatePixmap();
+
+#if QT_VERSION >= 0x040200
+
+	// Redirect to hide.
+	void close();
+
+#endif
 
 signals:
 
-    // Clicked signal.
-    void clicked();
-    // Context menu signal.
-    void contextMenuRequested(const QPoint& pos);
+	// Clicked signal.
+	void clicked();
+
+	// Context menu signal.
+	void contextMenuRequested(const QPoint& pos);
+
+#if QT_VERSION >= 0x040200
+
+protected slots:
+
+	// Handle systeam tray activity.
+	void activated(QSystemTrayIcon::ActivationReason);
+
+#else
 
 protected:
 
-    // Overriden mouse event method.
-    void mousePressEvent(QMouseEvent *);
+	// Self-drawable methods.
+	void paintEvent(QPaintEvent *);
+
+	// Overriden mouse event method.
+	void mousePressEvent(QMouseEvent *);
+
+#endif
+
+private:
+
+	// Instance pixmap and background color.
+#if QT_VERSION >= 0x040200
+	QIcon   m_icon;
+#endif
+	QPixmap m_pixmap;
+	QPixmap m_pixmapOverlay;
+	QColor  m_background;
 };
 
 
